extern int default_attribute_promotion;
extern int default_promote_invisible;
extern int default_keep_invisible;

extern int default_make_backup_files;
extern int default_net_consolidate;
